@@ -68,7 +68,7 @@ public:
      * Initialise the Dht with two open sockets (for IPv4 and IP6)
      * and an ID for the node.
      */
-    Dht(const int& s, const int& s6, const Config& config, const Logger& l = {});
+    Dht(std::unique_ptr<net::DatagramSocket>&& sock, const Config& config, const Logger& l = {});
     virtual ~Dht();
 
     /**
@@ -85,6 +85,8 @@ public:
         return std::max(getStatus(AF_INET), getStatus(AF_INET6));
     }
 
+    net::DatagramSocket* getSocket() const override { return network_engine.getSocket(); };
+
     /**
      * Performs final operations before quitting.
      */
@@ -111,16 +113,13 @@ public:
      * used to bootstrap efficiently from previously known nodes.
      */
     void insertNode(const InfoHash& id, const SockAddr&) override;
-    void insertNode(const InfoHash& id, const sockaddr* sa, socklen_t salen) override {
-        insertNode(id, SockAddr(sa, salen));
-    }
     void insertNode(const NodeExport& n) override {
         insertNode(n.id, SockAddr(n.ss, n.sslen));
     }
 
-    void pingNode(const sockaddr*, socklen_t, DoneCallbackSimple&& cb={}) override;
+    void pingNode(SockAddr, DoneCallbackSimple&& cb={}) override;
 
-    time_point periodic(const uint8_t *buf, size_t buflen, const SockAddr&) override;
+    time_point periodic(const uint8_t *buf, size_t buflen, SockAddr) override;
     time_point periodic(const uint8_t *buf, size_t buflen, const sockaddr* from, socklen_t fromlen) override {
         return periodic(buf, buflen, SockAddr(from, fromlen));
     }
